'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var reactJss = require('react-jss');
var vendorPrefixer = _interopDefault(require('jss-plugin-vendor-prefixer'));
var nested = _interopDefault(require('jss-plugin-nested'));
var clsx = _interopDefault(require('clsx'));

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}



var useStepperStyles =
/*#__PURE__*/
reactJss.createUseStyles({
  StepperContainer: {
    display: 'flex',
    alignItems: 'flex-start',
    flexDirection: 'row',
    padding: 24,
    fontFamily: 'Arial, Helvetica, sans-serif'
  }
});
var stepStyleDefaults = {
  activeBgColor: '#ed1d24',
  activeTextColor: '#ffffff',
  completedBgColor: '#a10308',
  completedTextColor: '#ffffff',
  inactiveBgColor: '#e0e0e0',
  inactiveTextColor: '#ffffff',
  size: '2em',
  circleFontSize: '1rem',
  labelFontSize: '0.875rem',
  borderRadius: '50%',
  fontWeight: 500
};
var useStepStyles =
/*#__PURE__*/
reactJss.createUseStyles({
  StepContainer: {
    flex: 1,
    position: 'relative',
    paddingLeft: 8,
    paddingRight: 8
  },
  StepMain: {
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center'
  },
  StepCircle: function StepCircle(props) {
    return {
      borderRadius: props.borderRadius,
      backgroundColor: props.inactiveBgColor,
      width: props.size,
      height: props.size,
      fontSize: '1em',
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center',
      '&.active': {
        backgroundColor: props.activeBgColor
      },
      '&.completed': {
        backgroundColor: props.completedBgColor
      }
    };
  },
  StepButton: {
    border: 'none',
    margin: 0,
    padding: 0,
    cursor: 'pointer'
  },
  StepCircleContent: function StepCircleContent(props) {
    return {
      color: props.inactiveTextColor,
      fontSize: props.circleFontSize,
      fontVariantNumeric: 'tabular-nums',
      '&.active': {
        color: props.activeTextColor
      },
      '&.completed': {
        color: props.completedTextColor
      }
    };
  },
  LabelContainer: function LabelContainer(props) {
    return {
      width: '100%',
      fontSize: props.labelFontSize,
      fontWeight: 400,
      lineHeight: 1.4
    };
  },
  Label: function Label(props) {
    return {
      display: 'block',
      marginTop: 16,
      textAlign: 'center',
      fontWeight: props.fontWeight
    };
  }
});
var useConnectorStyles =
/*#__PURE__*/
reactJss.createUseStyles({
  ConnectorContainer: {
    flex: '1 1 auto',
    top: 16,
    left: 'calc(-50% + 20px)',
    right: 'calc(50% + 20px)',
    position: 'absolute'
  },
  Connector: function Connector(props) {
    return {
      borderTopStyle: props.style,
      borderTopWidth: props.size,
      borderColor: props.disabledColor,
      display: 'block',
      '&.completed': {
        borderColor: props.completedColor
      },
      '&.active': {
        borderColor: props.activeColor
      }
    };
  }
});

var Connector = function Connector(_ref) {
  var _ref$completed = _ref.completed,
      completed = _ref$completed === void 0 ? false : _ref$completed,
      _ref$active = _ref.active,
      active = _ref$active === void 0 ? false : _ref$active,
      _ref$stateColors = _ref.stateColors,
      stateColors = _ref$stateColors === void 0 ? false : _ref$stateColors,
      _ref$connectorStyle = _ref.connectorStyle,
      connectorStyle = _ref$connectorStyle === void 0 ? {
    disabledColor: '#bdbdbd',
    activeColor: '#ed1d24',
    completedColor: '#a10308',
    size: 1,
    style: 'solid'
  } : _ref$connectorStyle;
  var classes = useConnectorStyles(_extends({}, connectorStyle, {
    completed: completed
  }));
  return React__default.createElement("div", {
    className: classes.ConnectorContainer
  }, React__default.createElement("span", {
    className: clsx(classes.Connector, {
      completed: completed && stateColors
    }, {
      active: active && stateColors
    })
  }));
};

var Step = function Step(_ref) {
  var children = _ref.children,
      _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      first = _ref.first,
      _ref$styleConfig = _ref.styleConfig,
      styleConfig = _ref$styleConfig === void 0 ? stepStyleDefaults : _ref$styleConfig,
      _ref$connectorStateCo = _ref.connectorStateColors,
      connectorStateColors = _ref$connectorStateCo === void 0 ? false : _ref$connectorStateCo,
      _ref$completed = _ref.completed,
      completed = _ref$completed === void 0 ? false : _ref$completed,
      _ref$active = _ref.active,
      active = _ref$active === void 0 ? false : _ref$active,
      className = _ref.className,
      rest = _objectWithoutPropertiesLoose(_ref, ["children", "label", "first", "styleConfig", "connectorStateColors", "completed", "active", "className"]);

  var stepStyleProps = _extends({}, styleConfig, {
    completed: completed,
    active: active
  });

  var classes = useStepStyles(stepStyleProps);
  return React.createElement("div", {
    className: classes.StepContainer
  }, !first && React.createElement(Connector, {
    completed: completed,
    active: active,
    stateColors: connectorStateColors
  }), React.createElement("div", {
    className: classes.StepMain
  }, React.createElement("button", Object.assign({
    disabled: !active && !completed,
    className: clsx(classes.StepCircle, classes.StepButton, {
      active: active
    }, {
      completed: completed
    }, className)
  }, rest), React.createElement("span", {
    className: clsx(classes.StepCircleContent, {
      active: active
    }, {
      completed: completed
    })
  }, children)), label && React.createElement("div", {
    className: classes.LabelContainer
  }, React.createElement("span", {
    className: classes.Label
  }, label))));
};

var generateId = function generateId(rule) {
  return "RFS-" + rule.key;
};

var createGenerateId = function createGenerateId() {
  return generateId;
};

reactJss.jss.setup({
  createGenerateId: createGenerateId
});
reactJss.jss.use(vendorPrefixer());
reactJss.jss.use(nested());

var Stepper = function Stepper(_ref) {
  var steps = _ref.steps,
      children = _ref.children,
      _ref$connectorStateCo = _ref.connectorStateColors,
      connectorStateColors = _ref$connectorStateCo === void 0 ? false : _ref$connectorStateCo,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$stepClassName = _ref.stepClassName,
      stepClassName = _ref$stepClassName === void 0 ? '' : _ref$stepClassName,
      _ref$activeStep = _ref.activeStep,
      activeStep = _ref$activeStep === void 0 ? 0 : _ref$activeStep,
      _ref$styleConfig = _ref.styleConfig,
      styleConfig = _ref$styleConfig === void 0 ? stepStyleDefaults : _ref$styleConfig;
  var classes = useStepperStyles();
  var childrenSteps = React__default.Children.toArray(children);

  var generateStepProps = function generateStepProps(index, activeStep) {
    return {
      key: index,
      className: stepClassName,
      children: index,
      completed: index < activeStep,
      active: index === activeStep,
      connectorStateColors: connectorStateColors,
      first: index === 0,
      styleConfig: styleConfig
    };
  };

  var stepsToRender = null;

  if (steps && steps.length > 0) {
    stepsToRender = steps.map(function (step, index) {
      return React__default.createElement(Step, Object.assign({}, generateStepProps(index, activeStep), step));
    });
  } else {
    stepsToRender = childrenSteps.map(function (childStep, index) {
      if (React__default.isValidElement(childStep)) {
        return React__default.cloneElement(childStep, _extends({}, generateStepProps(index, activeStep), {}, childStep.props));
      }

      return null;
    });
  }

  return React__default.createElement("div", {
    className: clsx(classes.StepperContainer, className)
  }, stepsToRender);
};

exports.Step = Step;
exports.Stepper = Stepper;
//# sourceMappingURL=react-form-stepper.cjs.development.js.map
